@@ -19,7 +19,7 @@
 
 using namespace Akonadi::Search::PIM;
 
-class Q_DECL_HIDDEN ContactQuery::Private
+class Akonadi::Search::PIM::ContactQueryPrivate
 {
 public:
     QString name;
@@ -29,20 +29,17 @@ public:
     QString any;
 
     int limit;
-    MatchCriteria criteria;
+    ContactQuery::MatchCriteria criteria;
 };
 
 ContactQuery::ContactQuery()
     : Query()
-    , d(new Private)
+    , d(new ContactQueryPrivate)
 {
     d->criteria = StartsWithMatch;
 }
 
-ContactQuery::~ContactQuery()
-{
-    delete d;
-}
+ContactQuery::~ContactQuery() = default;
 
 void ContactQuery::matchName(const QString &name)
 {
