@@ -7,8 +7,7 @@
  *
  */
 
-#ifndef AKONADI_SEARCH_PIM_SEARCHSTORE_H
-#define AKONADI_SEARCH_PIM_SEARCHSTORE_H
+#pragma once
 
 #include "xapiansearchstore.h"
 
@@ -39,7 +38,7 @@ protected:
         return QByteArray("akonadi");
     }
 
-    virtual Xapian::Query constructQuery(const QString &property, const QVariant &value, Term::Comparator com) override;
+    Xapian::Query constructQuery(const QString &property, const QVariant &value, Term::Comparator com) override;
     QUrl constructUrl(const Xapian::docid &docid) override;
 
     QHash<QString, QString> m_prefix;
@@ -60,4 +59,3 @@ protected:
 }
 }
 
-#endif // AKONADI_SEARCH_PIM_SEARCHSTORE_H
